@@ -148,9 +148,10 @@ configuration::configuration(FILE *glob, FILE *local) {
 
 configuration::~configuration(void) {
 
-  if (need_save) {
+  if (need_save && !f) 
+    f = create_local_config_file(".toppler.rc");
 
-    if (!f) f = create_local_config_file(".toppler.rc");
+  if (need_save && f) {
 
     fseek(f, 0, SEEK_SET);
 
@@ -180,7 +181,7 @@ configuration::~configuration(void) {
       t = t->next;
     }
   }
-  fclose(f);
+  if (f) fclose(f);
 
   config_data *t = first_data;
 
