@@ -30,6 +30,10 @@
    #include <strings.h>
 #endif // __QNXNTO__
 
+#ifdef XCODE
+   #include "osx.h"
+#endif
+
 #define NUMHISCORES 10
 
 #define SCOREFNAME "toppler.hsc"
@@ -115,21 +119,6 @@ static void loadscores(FILE *f) {
   }
 }
 
-static char * homedir()
-{
-
-#ifndef WIN32
-
-  return getenv("HOME");
-
-#else
-
-  return "./";
-
-#endif
-
-}
-
 static bool hsc_lock(void) {
 
 #ifndef WIN32
