@@ -79,20 +79,9 @@ void key_init(void) {
 
   SDL_EnableUNICODE(1);
 
-  if (joy_inited == 0) {
-    if (SDL_Init(SDL_INIT_JOYSTICK) < 0) {
-      joy_inited = 2;
-    } else {
-      joy = SDL_JoystickOpen(0);
-      if (!joy) {
-	joy_inited = 2;
-      } else {
-	SDL_JoystickEventState(SDL_ENABLE);
-	printf("Joystick enabled\n");
-	joy_inited = 1;
-      }
-    }
-  }
+// we are handling all joysticks from events, since this is just a placeholder
+// as we rip out this code line by line and replace with event code
+joy_inited = 2;
 
   chartyped = 0;
   keytyped = keydown = no_key;
@@ -110,6 +99,8 @@ static void handleEvents(void) {
     joy_action = 0;
   }
 
+    printf("In handleEvents\n");
+
   while (SDL_PollEvent(&e)) {
 
     switch (e.type) {
@@ -159,7 +150,7 @@ static void handleEvents(void) {
       break;
     case SDL_QUIT:
       fprintf(stderr, _("Wheee!!\n"));
-      throw new quit_action_class;
+      exit(1);
       break;
     case SDL_KEYDOWN:
     case SDL_KEYUP:
