@@ -214,6 +214,7 @@ static void add_mission(const char *fname, bool archive = false) {
       strcpy(n->fname, fname);
       n->prio = prio;
       n->next = m;
+      n->archive = archive;
 
       if (l)
         l->next = n;
@@ -299,7 +300,7 @@ void lev_findmissions() {
 
 #ifndef WIN32
 
-  snprintf(pathname, 100, "%s/.toppler/", getenv("HOME"));
+  snprintf(pathname, 100, "%s/.toppler/", homedir());
   n = alpha_scandir(pathname, &eps, missionfiles);
 
   if (n >= 0) {
@@ -315,7 +316,7 @@ void lev_findmissions() {
   free(eps);
   eps = NULL;
 
-  snprintf(pathname, 100, "%s/", TOP_DATADIR);
+  snprintf(pathname, 100, "%s/", datadir);
   n = alpha_scandir(pathname, &eps, missionfiles);
 
   if (n >= 0) {
