@@ -625,7 +625,7 @@ men_hiscores_background_proc(Menusystem *ms)
 
 static void show_scores(bool back = true, int mark = -1) {
   static char buf[50];
-  snprintf(buf, 50, _("Scores for %s"), lev_missionname(currentmission));
+  snprintf(buf, 50, _("Scores for %s"), _(lev_missionname(currentmission)));
   Menusystem ms(buf, men_hiscores_background_proc, 0, fontsprites.data(titledata)->h + 30);
 
   hsc_select(lev_missionname(currentmission));
