@@ -27,7 +27,7 @@
 #include "snowball.h"
 #include "level.h"
 #include "decl.h"
-#include "keyb.h"
+#include "event.h"
 #include "configuration.h"
 
 #include <string.h>
@@ -940,10 +940,10 @@ scr_putrect(int x, int y, int br, int h, Uint8 colr, Uint8 colg, Uint8 colb, Uin
 
 /* exchange active and inactive page */
 void scr_swap(void) {
-  if (!tt_has_focus) {
+  if (!events.has_focus()) {
       scr_darkenscreen();
       SDL_UpdateRect(display, 0, 0, 0, 0);
-      wait_for_focus();
+      events.wait_focus();
   }
   SDL_UpdateRect(display, 0, 0, 0, 0);
 }
